Module limits

Module limits 

Structs

MarginState
Aggregated margin state across all positions.
PositionData
Input data for a single position in margin calculations.
PositionLimits
Combined withdraw and borrow limits for a single market.

Functions

calculate_position_limits
Calculate withdraw and borrow limits for a single market.